When `margins = FALSE` a data frame with the (raw, normalized and linearized) estimated seasonal-ageing
indexes (SAI) corresponding to the set of integer ages determined by `min.age` and `max.age` and the ages
for which there is a least a death in the data frames introduced via the `x`, `y` and `...` arguments for
each combination of age and calendar quarter. The data frame has the following components:
- age
Integer age to which the SAIs corresponds.
- quarter.age
Age quarter to which the SAIs corresponds.
- quarter.calendar
Calendar (time, season) quarter to which the SAIs corresponds.
- SAI.raw
Estimates of raw seasonal-ageing indexes for each combination of `age`, `quarter.age` and `quarter.calendar`.
- SAI.norm
Estimates of seasonal-ageing indexes, attained after normalizing raw SAIs estimates, for each combination of `age`, `quarter.age` and `quarter.calendar`.
- SAI.lin
Final estimates of seasonal-ageing indexes, attained after linearizing normalized SAIs estimates, for each combination of `age`, `quarter.age` and `quarter.calendar`.
When `margins = TRUE` the output is a list with three data frames `SAI`, `SAI.age` and `SAI.quarter`.
`SAI` is defined as just described above. `SAI.age` and `SAI.quarter` contains, in a similar vein than `SAI`,
the estimated marginal SAIs, corresponding to, respectively, the age quarter and the calendar (time, season)
quarter.