Learn R Programming

qlifetable (version 0.0.2-4)

birth_2006: Half of male births recorded in the Comunitat Valenciana (Spain) during 2006.

Description

Data frame containing the dates of birth of a random sample composed by half of all male babies born in the region of Comunitat Valenciana (Spain) during 2006.

Usage

data(birth_2006)

Arguments

Format

A data frame containing 13,626 rows and 1 column:

date.birth

Dates of birth in format "yyyy-mm-dd".