Learn R Programming

qlifetable (version 0.0.2-4)

emi_2006: Male emigrants recorded in Comunitat Valenciana (Spain) during year 2006.

Description

Data frame containing the dates of birth and emigration of a random sample composed by half of all men who emigrated from the region of Comunitat Valenciana (Spain) during the year 2006.

Usage

data(emi_2006)

Arguments

Format

A data frame containing 18,006 rows and 2 columns:

date.birth

Dates of birth in format "yyyy-mm-dd".

date.emi

Dates of death in format "yyyy-mm-dd".