Learn R Programming

qlifetable (version 0.0.2-4)

pop_2006: Half of the male population living in the Comunitat Valenciana (Spain) on January, 1 2006.

Description

Data frame containing the dates of birth of a random sample composed by half of all men who were alive on 1 January 2006 in the region of Comunitat Valenciana (Spain).

Usage

data(pop_2006)

Arguments

Format

A data frame containing 1,197,154 rows and 1 column:

date.birth

Dates of birth in format "yyyy-mm-dd".