Learn R Programming

qlifetable (version 0.0.2-4)

time_exposed_outs: Data frame of time exposed at risk for a population of deaths/emigrants/exits (portfolio withdrawals, lapses) during the year of the event.

Description

Computes for each integer age and each combination of age and seasonal quarter the total time exposed at risk (in years) of a population of deceased/emigrants/exits (portfolio withdrawals, lapses) during the year of the event. The computation is performed using the associated data frame of quarterly variables corresponding to the population obtained using the quarterly_variables function.

Usage

time_exposed_outs(x)

Value

A data frame with the time exposed at risk for each (potential) combination of integer age and age and season quarter of the input dataset. The data frame has the following components:

age

Integer age to which the time exposed at risk corresponds.

quarter.age

Age quarter to which the time exposed at risk corresponds.

quarter.calendar

Calendar (time, season) quarter to which the time exposed at risk corresponds.

time.exposed

Total time (in years) exposed at risk of the population during the quarter determined for the combination of `age`, `quarter.age` and `quarter.calendar`.

Arguments

x

A data.frame output of the quarterly_variables function.

Author

Josep Lledo josep.lledo@uv.es

Jose M. Pavia pavia@uv.es

References

Pavia, JM and Lledo, J (2022). Estimation of the Combined Effects of Ageing and Seasonality on Mortality Risk. An application to Spain. *Journal of the Royal Statistical Society, Series A (Statistics in Society)*, 185(2), 471-497. tools:::Rd_expr_doi("10.1111/rssa.12769")

See Also

time_exposed_stock, time_exposed_newborns, time_exposed_ins

Examples

Run this code
dates.b <- c("1920-05-13", "1999-04-12", "2019-01-01")
dates.e <- c("2002-03-23", "2009-04-12", "2019-01-01")
x <- quarterly_variables(dates.b, dates.e)
out <- time_exposed_outs(x)

Run the code above in your browser using DataLab